unit RASManagerExample;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, ExtCtrls, Buttons, ToolWin, ComCtrls, RASManager, Spin;

type
  TRASForm = class(TForm)
    Messages: TRichEdit;
    ToolBar1: TToolBar;
    spConnect: TSpeedButton;
    SpeedButton4: TSpeedButton;
    Panel1: TPanel;
    eRASNames: TComboBox;
    Label1: TLabel;
    eAsync: TCheckBox;
    eTimeout: TSpinEdit;
    Label2: TLabel;
    SpeedButton2: TSpeedButton;
    SpeedButton1: TSpeedButton;
    Label3: TLabel;
    eUsername: TEdit;
    ePassword: TEdit;
    Label4: TLabel;
    RASManager: TRASManager;
    procedure FormCreate(Sender: TObject);
    procedure eRASNamesChange(Sender: TObject);
    procedure eAsyncClick(Sender: TObject);
    procedure eTimeoutChange(Sender: TObject);
    procedure SpeedButton1Click(Sender: TObject);
    procedure RASManagerConnecting(Sender: TObject; Msg, State,
      Error: Integer);
    procedure spConnectClick(Sender: TObject);
    procedure RASManagerError(Sender: TObject; Error: Integer);
    procedure RASManagerTimeout(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure SpeedButton4Click(Sender: TObject);
  private
    { Private-Deklarationen }
    procedure Information( const Msg: string );
  public
    { Public-Deklarationen }
  end;

var
  RASForm: TRASForm;

implementation

uses AboutDialog;

{$R *.DFM}

procedure TRASForm.Information( const Msg: string );
begin
  Messages.Lines.Add( Msg );
end;

procedure TRASForm.FormCreate(Sender: TObject);
begin
  GetRasNames( eRASNames.Items );           // get all ras names
  if eRASNames.Items.Count <> 0 then begin  // set the combo box to the first name
    eRASNames.ItemIndex := 0;
  end;
  // update all RASManager entrys
  eRASNamesChange( self );
  eAsyncClick( self );
  eTimeoutChange( self );
end;

procedure TRASForm.eRASNamesChange(Sender: TObject);
begin
  // set the RAS name within RASManager
  RASManager.RASName := eRASNames.Items[eRASNames.ItemIndex];
  eUsername.Text := RASManager.Username;  // refresh der shown username
  ePassword.Text := RASManager.Password;  // refresh the shown password
  spConnect.Down := RasManager.Connected; // check if the button state is right
end;

procedure TRASForm.eAsyncClick(Sender: TObject);
begin
  RASManager.DialAsync := eAsync.Checked;
end;

procedure TRASForm.eTimeoutChange(Sender: TObject);
begin
  RASManager.Timeout := eTimeout.Value;
end;

procedure TRASForm.SpeedButton1Click(Sender: TObject);
begin
  Messages.Lines.Clear;
end;

procedure TRASForm.RASManagerConnecting(Sender: TObject; Msg, State,
  Error: Integer);
begin
  // sorry i do not really know the meaning of the returned codes
  Information( 'dial message state error ' + IntToStr(Msg) +
               ' ' + IntToStr(State) + ' ' + IntToStr(Error) );
end;

procedure TRASForm.spConnectClick(Sender: TObject);
begin
  if RasManager.Connected then begin
    RASManager.DisConnect;     // disconnect the service
    spConnect.Down := false;   // and refresh the button
  end else begin
    RASManager.Connect;        // connect the service
    spConnect.Down := true;    // be sure it is the right button state
  end;
end;

procedure TRASForm.RASManagerError(Sender: TObject; Error: Integer);
begin
  // sorry i do not really know the meaning of the returned codes
  if Error <>0 then begin
    Information( 'RAS ERROR occurred ' + IntToStr(Error) );
    RASManager.DisConnect;       // better try to disconnect
    spConnect.Down := false;     // and refresh the button state
  end;
end;

procedure TRASForm.RASManagerTimeout(Sender: TObject);
begin
  // sorry i do not really know the meaning of the returned codes
  Information( 'RAS TIMEOUT occurred ' );
  RASManager.DisConnect;       // disconnect because timeout
  spConnect.Down := false;     // and refresh the button state
end;

procedure TRASForm.FormDestroy(Sender: TObject);
begin
  if RasManager.Connected then begin // if ras is connected
    RASManager.DisConnect;           // disconnect the service
  end;
end;

procedure TRASForm.SpeedButton4Click(Sender: TObject);
begin
  AboutForm.ShowModal( RASManager.Version );
end;

end.
